@@ -8,7 +8,7 @@
 require 'date'
 
 module Optimist
-VERSION = "3.2.0"
+VERSION = "3.2.1"
 
 ## Thrown by Parser in the event of a commandline error. Not needed if
 ## you're using the Optimist::options entry.
@@ -208,7 +208,7 @@ class Parser
     o = Option.create(name, desc, opts)
 
     raise ArgumentError, "you already have an argument named '#{name}'" if @specs.member? o.name
-    
+
     o.long.names.each do |lng|
       raise ArgumentError, "long option name #{lng.inspect} is already taken; please specify a (different) :long/:alt" if @long[lng]
       @long[lng] = o.name
@@ -754,7 +754,7 @@ class ShortNames
              end
 
       if sopt =~ INVALID_ARG_REGEX
-        raise ArgumentError, "short option name '#{sopt}' can't be a number or a dash" 
+        raise ArgumentError, "short option name '#{sopt}' can't be a number or a dash"
       end
       @chars << sopt
     end
@@ -820,7 +820,7 @@ class Option
     optionlist = []
     optionlist.concat(short.chars.map { |o| "-#{o}" })
     optionlist.concat(long.names.map { |o| "--#{o}" })
-    optionlist.compact.join(', ') + type_format + (flag? && default ? ", --no-#{long}" : "")
+    optionlist.compact.join(', ') + type_format + (flag? && default ? ", --no-#{long.long}" : "")
   end
 
   ## Format the educate-line description including the default and permitted value(s)
@@ -880,7 +880,7 @@ class Option
     end
     true
   end
-  
+
   # incoming values from the command-line should be strings, so we should
   # stringify any permitted types as the basis of comparison.
   def permitted_value?(val)
